pub fn node_addrs<G>(g: G) -> HashMap<G::NodeId, ContentAddr>Expand description
Hash all the nodes and return a map from node IDs to their content addresses.
pub fn node_addrs<G>(g: G) -> HashMap<G::NodeId, ContentAddr>Hash all the nodes and return a map from node IDs to their content addresses.